server_client_20141211_175217

### config2

Total tests | Passed | Failed | Skipped | Execution time | Naarad
--- | --- | --- | --- | --- | ---
12 | 4 | 8 | 0 | 152.509639025 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test_negative_correctness | Passed | Tests sending non-integers to the server
test_client_isolation | Failed | Tests what happens when the client is faulty
test_bouncing_with_state | Failed | Tests that bouncing the server retains state
test_multi_client_perf | Failed | Tests the performance of a server when handling multiple clients
test_client_timeout | Failed | Tests what happens when the client does not finish a full request
test_race_condition | Failed | Tests what happens when two clients send requests to the same server
test_fault_tolerance | Passed | Tests what happens when servers are stopped
test_redlining | Failed | Sends a large sample of integers to the server.
test_single_client_perf | Failed | Tests the performance of a server when handling single client
test_ordered_events | Passed | Tests that integers to a server are received in the same order that they are sent
test_correctness | Failed | Tests if the correct sums are calculated
test_load_balance | Passed | Tests if clients perform correct load balancing